.. image:: https://travis-ci.org/python-openxml/python-docx.svg?branch=master
   :target: https://travis-ci.org/python-openxml/python-docx

*python-docx-valutico* is a Python library for creating and updating Microsoft Word
(.docx) files.

This is basically the same as *python-docx*, but with added support for charts.

More information is available in the `python-docx documentation`_.

.. _`python-docx documentation`:
   https://python-docx.readthedocs.org/en/latest/
